==> qmmp-0.12.20.tar.bz2: qmmp-0.12.20/src/plugins/General/fileops/translations/fileops_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>FileOps</name>
    <message>
        <location filename="../fileops.cpp" line="97"/>
        <location filename="../fileops.cpp" line="140"/>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="98"/>
        <location filename="../fileops.cpp" line="141"/>
        <source>Destination directory doesn&apos;t exist</source>
        <translation>Тека призначення не існує</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="144"/>
        <source>Move Files</source>
        <translation>Переміщення файлів</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="145"/>
        <source>Are you sure you want to move %n file(s)?</source>
        <translation>
            <numerusform>Ви дійсно бажаєте перемістити %n файл?</numerusform>
            <numerusform>Ви дійсно бажаєте перемістити %n файла?</numerusform>
            <numerusform>Ви дійсно бажаєте перемістити %n файлів?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="161"/>
        <source>Copying</source>
        <translation>Копіювання</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="162"/>
        <location filename="../fileops.cpp" line="259"/>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="207"/>
        <source>Copying file %1/%2</source>
        <translation>Копіювання файла %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="258"/>
        <source>Moving</source>
        <translation>Переміщення</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="297"/>
        <source>Moving file %1/%2</source>
        <translation>Переміщення файла %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="113"/>
        <source>Remove Files</source>
        <translation>Видалення файлів</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="114"/>
        <source>Are you sure you want to remove %n file(s) from disk?</source>
        <translation>
            <numerusform>Ви дійсно бажаєте видалити %n файл з диску?</numerusform>
            <numerusform>Ви дійсно бажаєте видалити %n файла з диску?</numerusform>
            <numerusform>Ви дійсно бажаєте видалити %n файлів з диску?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FileOpsFactory</name>
    <message>
        <location filename="../fileopsfactory.cpp" line="30"/>
        <source>File Operations Plugin</source>
        <translation>Модуль файлових операцій</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="50"/>
        <source>About File Operations Plugin</source>
        <translation>Про модуль файлових операцій</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="51"/>
        <source>Qmmp File Operations Plugin</source>
        <translation>Модуль роботи з файлами для Qmmp</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>Поміняти комбінацію клавіш</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>Натисніть клавіші, комбінацію яких ви бажаєте використовувати</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="43"/>
        <source>Clear</source>
        <translation>Очистити</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="51"/>
        <location filename="../settingsdialog.cpp" line="131"/>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="52"/>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>Rename</source>
        <translation>Переіменувати</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <location filename="../settingsdialog.cpp" line="54"/>
        <location filename="../settingsdialog.cpp" line="134"/>
        <source>Remove</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="137"/>
        <source>New action</source>
        <translation>Нова дія</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <location filename="../settingsdialog.cpp" line="133"/>
        <source>Move</source>
        <translation>Перемістити</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="232"/>
        <source>Choose a directory</source>
        <translation>Виберіть теку</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Operations Settings</source>
        <translation>Налаштування файлових операцій</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Enabled</source>
        <translation>Увімкнено</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="53"/>
        <source>Operation</source>
        <translation>Операція</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Menu text</source>
        <translation>Текст меню</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Shortcut</source>
        <translation>Комбінація клавіш</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="126"/>
        <location filename="../settingsdialog.ui" line="143"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Destination:</source>
        <translation>Призначення:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="133"/>
        <source>File name pattern:</source>
        <translation>Формат імені файла:</translation>
    </message>
</context>
</TS>

==> qmmp-1.1.7.tar.bz2: qmmp-1.1.7/src/plugins/General/fileops/translations/fileops_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>FileOps</name>
    <message>
        <location filename="../fileops.cpp" line="98"/>
        <location filename="../fileops.cpp" line="132"/>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="99"/>
        <location filename="../fileops.cpp" line="133"/>
        <source>Destination directory doesn&apos;t exist</source>
        <translation>Тека призначення не існує</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="136"/>
        <source>Move Files</source>
        <translation>Переміщення файлів</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="137"/>
        <source>Are you sure you want to move %n file(s)?</source>
        <translation>
            <numerusform>Ви дійсно бажаєте перемістити %n файл?</numerusform>
            <numerusform>Ви дійсно бажаєте перемістити %n файла?</numerusform>
            <numerusform>Ви дійсно бажаєте перемістити %n файлів?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="153"/>
        <source>Copying</source>
        <translation>Копіювання</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="154"/>
        <location filename="../fileops.cpp" line="244"/>
        <source>Stop</source>
        <translation>Зупинити</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="199"/>
        <source>Copying file %1/%2</source>
        <translation>Копіювання файла %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="243"/>
        <source>Moving</source>
        <translation>Переміщення</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="276"/>
        <source>Moving file %1/%2</source>
        <translation>Переміщення файла %1/%2</translation>
    </message>
    <message>
        <location filename="../fileops.cpp" line="114"/>
        <source>Remove Files</source>
        <translation>Видалення файлів</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileops.cpp" line="115"/>
        <source>Are you sure you want to remove %n file(s) from disk?</source>
        <translation>
            <numerusform>Ви дійсно бажаєте видалити %n файл з диску?</numerusform>
            <numerusform>Ви дійсно бажаєте видалити %n файла з диску?</numerusform>
            <numerusform>Ви дійсно бажаєте видалити %n файлів з диску?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>FileOpsFactory</name>
    <message>
        <location filename="../fileopsfactory.cpp" line="30"/>
        <source>File Operations Plugin</source>
        <translation>Модуль файлових операцій</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="50"/>
        <source>About File Operations Plugin</source>
        <translation>Про модуль файлових операцій</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="51"/>
        <source>Qmmp File Operations Plugin</source>
        <translation>Модуль роботи з файлами для Qmmp</translation>
    </message>
    <message>
        <location filename="../fileopsfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>Поміняти комбінацію клавіш</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>Натисніть клавіші, комбінацію яких ви бажаєте використовувати</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="43"/>
        <source>Clear</source>
        <translation>Очистити</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="51"/>
        <location filename="../settingsdialog.cpp" line="131"/>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="52"/>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>Rename</source>
        <translation>Переіменувати</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <location filename="../settingsdialog.cpp" line="54"/>
        <location filename="../settingsdialog.cpp" line="134"/>
        <source>Remove</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="137"/>
        <source>New action</source>
        <translation>Нова дія</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="220"/>
        <source>Artist</source>
        <translation>Виконавець</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="221"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="222"/>
        <source>Album Artist</source>
        <translation>Альбом Виконавець</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="223"/>
        <source>Title</source>
        <translation>Назва</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="224"/>
        <source>Track Number</source>
        <translation>Номер доріжки</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="225"/>
        <source>Two-digit Track Number</source>
        <translation>Подвійний номер доріжки</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="226"/>
        <source>Genre</source>
        <translation>Жанр</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="230"/>
        <source>Disc Number</source>
        <translation>Номер диску</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="231"/>
        <source>File Name</source>
        <translation>Ім&apos;я файла</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="232"/>
        <source>File Path</source>
        <translation>Шлях файла</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="233"/>
        <source>Year</source>
        <translation>Рік</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="227"/>
        <source>Comment</source>
        <translation>Коментар</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <location filename="../settingsdialog.cpp" line="133"/>
        <source>Move</source>
        <translation>Перемістити</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="228"/>
        <source>Composer</source>
        <translation>Композитор</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="229"/>
        <source>Duration</source>
        <translation>Тривалість</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="234"/>
        <source>Condition</source>
        <translation>Умова</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="247"/>
        <source>Choose a directory</source>
        <translation>Виберіть теку</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>File Operations Settings</source>
        <translation>Налаштування файлових операцій</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Enabled</source>
        <translation>Увімкнено</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="53"/>
        <source>Operation</source>
        <translation>Операція</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>Menu text</source>
        <translation>Текст меню</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Shortcut</source>
        <translation>Комбінація клавіш</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="126"/>
        <location filename="../settingsdialog.ui" line="143"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Destination:</source>
        <translation>Призначення:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="133"/>
        <source>File name pattern:</source>
        <translation>Формат імені файла:</translation>
    </message>
</context>
</TS>
